merchize library

Classes

Attachment
File đính kèm ticket
AttributeValue
Value of a product attribute.
Collection
Represents a product collection in Merchize.
Contact
Contact information in the ticket response
Conversation
Represents a conversation inside a ticket.
CreateTicketRequest
Request body để tạo ticket mới qua API (Merchize).
Freshdesk
Represents the Freshdesk metadata for the ticket.
FreshdeskCustomFields
Represents the custom fields inside a Freshdesk ticket.
FreshdeskTicket
Chi tiết ticket trong Freshdesk
FulfillmentCostDetail
Represents breakdown of fulfillment costs for an order.
FulfillmentCostInvoice
Fulfillment cost details for the order.
FulfillmentLocation
Fulfillment location of a product.
ImportOrder
Represents the status information of an order.
Invoice
Represents invoice details for an order.
Merchize
MerchizeResponse<T>
OptionAttribute
Attribute metadata for a variant option (e.g., Size, Color).
Order
Represents an order to be imported into Merchize system.
OrderDetail
Represents an order detail in Merchize API.
OrderDetailItem
Represents an item in an order.
OrderInvoice
Represents an invoice of an order from Merchize.
OrderItem
Represents a product item inside the order.
OrderItemAttribute
Represents an attribute of an order item (e.g., Size: S, Color: Black).
OrderProgress
Represents a single progress step of an order
OrderProgressDetail
Represents detail of a single order progress
OrderTicket
Represents an Order Ticket response containing tickets related to an order.
OrderTicketItem
Represents a single support ticket.
OrderTracking
Represents a fulfilled order tracking response from Merchize.
OrderTrackingItem
Represents a product item inside an order tracking response.
PackageProgress
Represents package-level progress
PackageProgressEvent
Represents an event in package progress
Paging<T>
Product
Represents a Product in Merchize.
ProductAttribute
Attribute of a product (e.g., size, color).
ProductVariant
Product variant with its attributes, prices, and tiers.
ShippingInfo
Represents shipping address information of the order.
ShippingPrice
Shipping fee info of a variant by country/zone.
Ticket
Đại diện cho một Ticket, dùng để tạo/gọi API qua retrofit.dart
TicketImage
Đại diện cho ảnh đính kèm ticket
Tier
Price tier info of a variant.
UpdateReopenTicketRequest
Request model for reopening a ticket
UpdateTicket
Represents the response when updating a ticket (adding a comment or email reply).
UpdateTicketRequest
Request model for updating a ticket (comment on a ticket)
Variant
Represents a product variant in Merchize.
VariantAttribute
Attribute of a product variant.
VariantOption
Represents an option of a variant (e.g., Size: S, Color: Black).

Enums

Action