Product class

Represents a Product in Merchize.

Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

Product({required String id, required String title, required List<String> printingMethods, required FulfillmentLocation fulfillmentLocation, required String sku, required List<ProductAttribute> attributes, required List<ProductVariant> variants, required String mockupAndTemplatesLink})
Product.fromJson(Map<String, dynamic> json)
factory

Properties

attributes List<ProductAttribute>
Array of attributes, to specify product's featured attributes.
final
fulfillmentLocation FulfillmentLocation
Information of product's fulfillment location.
final
hashCode int
The hash code for this object.
no setterinherited
id String
ID of the product.
final
Link to mockup & templates of the product.
final
printingMethods List<String>
Array of printing methods that the product supports.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sku String
SKU of the product.
final
title String
The name of the product.
final
variants List<ProductVariant>
Array of variant information.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited